@@ -9,7 +9,7 @@ use feature ":5.10";
 use Config;
 use File::Spec::Functions qw(catdir rel2abs splitpath);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use constant DFLT_TOCOPY_SECTION  => "__TOCOPY__";
 
@@ -218,7 +218,7 @@ my $_parse_ini = sub {
         . ($exp_flag ? $self->$_expand_value($curr_section, $value) : $value);
     } elsif ($modifier eq ':') {
       delete $expanded->{$x_var_name} if $exp_flag; # Needed to make _expand_vars corectly!
-      $sect_vars->{$var_name} = $self->$_expand_vars($curr_section, $var_name, $value);
+      $sect_vars->{$var_name} = $self->$_expand_vars($curr_section, $var_name, $value, undef, 1);
     } elsif ($modifier eq '+>') {
       if (exists($sect_vars->{$var_name})) {
         $sect_vars->{$var_name} =
@@ -400,7 +400,7 @@ $_x_var_name = sub {
 
 
 $_expand_vars = sub {
-  my ($self, $curr_sect, $variable, $value, $seen) = @_;
+  my ($self, $curr_sect, $variable, $value, $seen, $not_seen) = @_;
   my $top = !$seen;
   my @result = ("");
   my $level = 0;
@@ -411,7 +411,7 @@ $_expand_vars = sub {
                                                        || $var_basename =~ /^=ENV:/);
     croak("recursive variable '", $x_variable_name, "' references itself")
       if exists($seen->{$x_variable_name});
-    $seen->{$x_variable_name} = undef;
+    $seen->{$x_variable_name} = undef if !$not_seen;
   }
   foreach my $token (split(/(\$\(|\))/, $value)) {
     if ($token eq '$(') {
@@ -472,7 +472,7 @@ Config::INI::RefVars - INI file reader, allows the referencing of INI and enviro
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =head1 SYNOPSIS
 
@@ -751,6 +751,14 @@ This results in the variable C<var> having the value C<$(FOO)>. It works
 because C<$()> always expands to an empty string (see section L</"PREDEFINED
 VARIABLES">).
 
+Recursive references are not possible, an attempt to do so leads to a fatal
+error. However, you can do this with the C<:=> assignment:
+
+   a=omethin
+   a:=s$(a)g
+
+C<a> has the value C<something>. However, due to the way C<:=> works, this is
+not really a recursive reference.
 
 =head3 Referencing Variables of other Sections
 
@@ -794,6 +802,8 @@ C<$(=)> expands to the name of the current section.
 =item C<==>
 
 C<$(==)> expands to the name of the variable that is currently being defined.
+Think of this as a pseudo-variable, something like $([SECTION]==) always
+results in an empty string.
 
 =back
 
